@@ -8,9 +8,16 @@
 # Rubys RSpec that got me longing for a similar syntax
 # Robert who suggested lots of great api ideas
 
+# TODO: 
+# - Ensure no matcher disapears during an update
+# - get build server + button on bitbucket
+# - get coverage + button on bitbucket
+# - get documentation + button on bitbucket
+# Improve py3 support - shorten exception stack traces
+
 __all__ = ['expect']
 
-import re
+import re, sys
 
 class expect(object):
     """Minimal but very flexible implementation of the expect pattern.
@@ -90,70 +97,84 @@ class expect(object):
     # All public methods on this class are expected to be matchers.
     # Beware the consequences if you break this promise. :)
     
-    # On naming matchers: Their name should be clear and fit in with the naming scheme of the existing 
-    # matchers. That is: short, active, prepended with a conjugation of be
-    # Sensible alternative names are encouraged after the method definition to allow the matchers
-    # To be used sensibly in a sentence like matter for those who want it
-    # REFACT: consider switching to the short form as the default and prefer to get the combinations from the 
-    # arbitrary chaining support?
+    # On naming matchers: 
+    # Their name should be clear and fit in with the naming scheme of the existing matchers. 
+    # That is: short and active if possible. Matcher names should fullfill two roles. 
+    # They should allow direct usage, without chaining in front of them:
+    #    expect(3).equals(3)
+    # They should also allow chaining to read more like a sentence:
+    #    expect(3).to.equal(3)
+    #    expect(3).is_.equal(3)
+    # If sensible, also support an operator overloaded forms:
+    #    expect(3) == 3
+    # The goal is to allow the code to read sensible and as similar to the generated error message as possible.
+    # Include as many alternative names as make sense.
+    
+    # Right now some be_ prefixes are included as aliasses, but I'm feeling confident that I will probably phase 
+    # them out in favor of using arbitrary chaining to achieve their effect.
     
     # On debugging matchers: Some pyton debuggers will hide all the internals of the expect method
     # To match py.tests behaviour. Read up on hidden frames and how to unhide them in your python debugger
     # `hf_unhide` is often the keyword here.
     
-    # REFACT: on the one hand the aliasses are really nice to to use, on the other hand they create ambiguity
-    # because not all names are completely coherent. Maybe it is better to abandon them and just allow 'not_' 
-    # prefixes and do the rest via arbitrary chaining?
-    
-    def is_true(self):
+    def true(self):
         self._assert(self._expected is True, "to be True")
     
-    true = is_true
+    is_true = true
     
-    def is_false(self):
+    def false(self):
         self._assert(self._expected is False, "to be False")
     
-    false = is_false
+    is_false = false
     
-    def is_none(self):
+    def none(self):
         self._assert(self._expected is None, "to be None")
     
-    none = is_none
+    is_none = none
     
+    def exist(self):
+        self._assert(self._expected is not None, "to exist (not be None)")
+    exists = exist
     # REFACT: consider adding 'from' alias to allow syntax like expect(False).from(some_longish_expression())
     # Could enhance readability, not sure it's a good idea?
-    def is_equal(self, something):
-        self._assert(something == self._expected, "to be equal to {0!r}", something)
+    def equal(self, something):
+        self._assert(something == self._expected, "to equal {0!r}", something)
     
-    __eq__ = equals = equal = to_equal = is_equal
+    __eq__ = equals = equal
+    to_equal = is_equal = equal
     
-    def is_different(self, something):
+    def different(self, something):
         self.not_ == something
     
-    __ne__ = is_different
+    __ne__ = different
+    is_different = different
     
-    def to_be(self, something):
+    def be(self, something):
         self._assert(something is self._expected, "to be {0!r}", something)
     
-    is_ = be = be_same = is_same = be_identical = is_identical = to_be
+    same = identical = is_ = be
+    be_same = is_same = be_identical = is_identical = to_be = be
     
-    def is_trueish(self):
+    def trueish(self):
         self._assert(bool(self._expected) is True, "to be trueish")
     
-    truthy = truish = trueish = is_trueish
+    truthy = truish = trueish
+    is_trueish = trueish
     
-    def is_falseish(self):
+    def falseish(self):
         self._assert(bool(self._expected) is False, "to be falseish")
     
-    falsy = falsish = falseish = is_falseish
+    falsy = falsish = falseish
+    is_falseish = falseish
     
-    def does_include(self, *needles):
+    def includes(self, *needles):
         for needle in needles:
             self._assert(needle in self._expected, "to include {0!r}", needle)
     
-    contain = contains = to_include = include = includes = does_include
+    contain = contains = include = includes
+    does_include = to_include = includes
     
-    def is_included_in(self, sequence_or_atom, *additional_atoms):
+    def within(self, sequence_or_atom, *additional_atoms):
         sequence = sequence_or_atom
         if len(additional_atoms) > 0:
             sequence = [sequence_or_atom]
@@ -161,30 +182,34 @@ class expect(object):
         
         self._assert(self._expected in sequence, "is included in {0!r}", sequence)
     
-    in_ = included_in = is_included_in
+    in_ = included_in = within
+    is_within = is_included_in = within
     
-    def has_sub_dict(self, a_subdict=None, **kwargs):
-        assert isinstance(self._expected, dict), self._message("to be a dictionary", self._expected)
+    def sub_dict(self, a_subdict=None, **kwargs):
+        expect(self._expected).is_instance(dict)
         
         if a_subdict is None:
             a_subdict = dict()
         a_subdict.update(kwargs)
         
         actual_keys = a_subdict.keys()
-        actual_items = a_subdict.items()
+        actual_items = list(a_subdict.items())
         expected_items = [(key, self._expected.get(key)) for key in actual_keys]
         # superset = set(self._expected.iteritems())
         # REFACT: subset.issubset(superset)
         self._assert(expected_items == actual_items, 'to contain dict {0!r}', a_subdict)
     
-    includes_dict = contains_dict = sub_dict = subdict = have_subdict = have_sub_dict = has_subdict = has_sub_dict
+    includes_dict = contains_dict = subdict = sub_dict
+    have_subdict = have_sub_dict = has_subdict = has_sub_dict = sub_dict
     
     def to_match(self, regex):
-        assert isinstance(self._expected, basestring), self._message("to be a string")
+        string_type = str if sys.version > '3' else basestring
+        expect(self._expected).is_instance(string_type)
         
         self._assert(re.search(regex, self._expected) is not None, "to be matched by regex r{0!r}", regex)
     
-    match = matches = is_matching = to_match
+    match = matching = matches = to_match
+    is_matching = to_match
     
     # TODO: consider with statement support to allow code like this
     # with expect.raises(AssertionError):
@@ -197,12 +222,13 @@ class expect(object):
         """
         # REFACT: consider to change to_raise to let all unexpected exceptions pass through
         # Not sure what that means to correctly implement the negative side though
-        assert callable(self._expected), "Expect {0!r} to be callable".format(self._expected)
+        expect(self._expected).is_callable()
         
-        # import sys; sys.stdout = sys.__stdout__; from bpdb import set_trace; set_trace()
         caught_exception = None
-        try: self._expected()
-        except BaseException as exception: caught_exception = exception
+        try:
+            self._expected()
+        except BaseException as exception:
+            caught_exception = exception
         
         is_right_class = isinstance(caught_exception, exception_class)
         if message_regex is None:
@@ -213,55 +239,77 @@ class expect(object):
             self._assert(is_right_class and has_matching_message, 
                 "to raise {0} with message matching:\n\tr'{1}'\nbut it raised:\n\t{2!r}", 
                 exception_class.__name__, message_regex, caught_exception)
+        
+        return caught_exception
     
-    throws = is_throwing = raise_ = raises = is_raising = to_raise
+    throw = throwing = throws = raise_ = raising = raises = to_raise
+    is_raising = is_throwing = to_raise
     
-    def is_empty(self):
+    def empty(self):
         self._assert(len(self._expected) == 0, "to be empty")
     
-    empty = is_empty
+    is_empty = empty
     
-    def is_instance(self, a_class):
+    def instance_of(self, a_class):
         self._assert(isinstance(self._expected, a_class), "to be instance of '{0}'", a_class.__name__)
     
-    instanceof = is_instance_of = instance_of = isinstance = is_instance
+    isinstance = instanceof = instance_of
+    is_instance = is_instance_of = instance_of
     
-    def has_length(self, a_length):
-        self._assert(len(self._expected) == a_length, "to have length {0}", a_length)
+    def is_callable(self):
+        self._assert(callable(self._expected) is True, "to be callable")
     
-    len = length = count = has_count = has_length
+    callable = is_callable
     
-    def is_greater(self, smaller):
-        self._assert(self._expected > smaller, "to be greater then {0!r}", smaller)
+    def length(self, a_length):
+        actual = len(self._expected)
+        self._assert(actual == a_length, "to have length {0}, but found length {1}", a_length, actual)
     
-    __gt__ = bigger = bigger_then = larger = larger_then = is_greater_then = is_greater
+    len = count = length
+    has_count = has_length = length
     
-    def is_greater_or_equal(self, smaller_or_equal):
-        self._assert(self._expected >= smaller_or_equal, "to be greater or equal then {0!r}", smaller_or_equal)
+    def greater_than(self, smaller):
+        self._assert(self._expected > smaller, "to be greater than {0!r}", smaller)
     
-    __ge__ = greater_or_equal_then = is_greater_or_equal_then = greater_or_equal = is_greater_or_equal
+    __gt__ = bigger = larger = larger_than = greater = greater_than
+    is_greater_than = is_greater = greater_than
+    # TODO: consider to include *_then because it's such a common error?
     
-    def is_less_then(self, greater):
-        self._assert(self._expected < greater, "to be less then {0!r}", greater)
+    def greater_or_equal(self, smaller_or_equal):
+        self._assert(self._expected >= smaller_or_equal, "to be greater or equal than {0!r}", smaller_or_equal)
     
-    __lt__ = smaller = smaller_then = lesser = lesser_then = less_then = smaller_then = is_smaller_then = is_less_then
+    __ge__ = greater_or_equal_than = greater_or_equal
+    is_greater_or_equal_than = is_greater_or_equal = greater_or_equal
+    # TODO: consider to include *_then because it's such a common error?
     
-    def is_less_or_equal(self, greater_or_equal):
-        self._assert(self._expected <= greater_or_equal, "to be less or equal then {0!r}", greater_or_equal)
+    def less_than(self, greater):
+        self._assert(self._expected < greater, "to be less than {0!r}", greater)
     
-    __le__ = smaller_or_equal = smaller_or_equal_then = is_smaller_or_equal = is_smaller_or_equal_then = is_less_or_equal_then = is_less_or_equal
+    __lt__ = smaller = smaller_than = lesser = lesser_than = less = less_than
+    is_smaller_than = is_less_than = less_than
+    # TODO: consider to include *_then because it's such a common error?
     
-    # TODO: consider adding is_within_exclusive_range
+    def less_or_equal(self, greater_or_equal):
+        self._assert(self._expected <= greater_or_equal, "to be less or equal than {0!r}", greater_or_equal)
+    
+    __le__ = smaller_or_equal = smaller_or_equal_than = lesser_or_equal = lesser_or_equal_than = less_or_equal_than = less_or_equal
+    is_smaller_or_equal = is_smaller_or_equal_than = is_less_or_equal_than = is_less_or_equal = less_or_equal
+    # TODO: consider to include *_then because it's such a common error?
+    
+    # TODO: consider adding is_between_exclusive
     # TODO: consider supporting slice syntax as alias. expect(3)[2:4] doesn't look natural though
-    def is_within_range(self, lower, higher):
+    # REFACT: consider to change to be more like range(), i.e. lower bound included, upper bound excluded
+    def between(self, lower, higher):
         self._assert(lower <= self._expected <= higher, "to be between {0!r} and {1!r}", lower, higher)
     
-    is_between = is_within = is_within_range
+    within_range = between
+    is_within_range = is_between = between
     
-    def is_close(self, actual, delta):
-        self._assert((actual - delta) <= self._expected <= (actual + delta), "to be close to {0!r} with max delta {1!r}", actual, delta)
+    def close_to(self, actual, max_delta):
+        self._assert((actual - max_delta) <= self._expected <= (actual + max_delta), "to be close to {0!r} with max delta {1!r}", actual, max_delta)
     
-    is_about = about = almost_equal = is_almost_equal = close_to = is_close_to = is_close
+    about_equals = about_equal = about = almost_equals = almost_equal = close = close_to
+    is_about =  is_almost_equal = is_close = is_close_to = close_to
     
     ## Internals ########################################################################################
     
@@ -327,7 +375,10 @@ class expect(object):
         # Make the stacktrace easier to read by tricking python to shorten the stack trace to this method.
         # Hides the actual matcher and all the methods it calls to assert stuff.
         try:
-            self._selected_matcher(*args, **kwargs)
+            return_value = self._selected_matcher(*args, **kwargs)
+            if self._should_raise:
+                # if not, we want to return True
+                return return_value
         except AssertionError as assertion:
             if self._should_raise:
                 raise assertion
@@ -397,10 +448,11 @@ class expect(object):
             if not name.startswith('_'):
                 matcher = object.__getattribute__(cls, name)
                 public_matchers_by_matcher[matcher] = name
+        public_matchers = list(public_matchers_by_matcher.keys())
         
         for special_name in special_names:
             matcher = object.__getattribute__(cls, special_name)
-            if matcher in public_matchers_by_matcher.keys():
+            if matcher in public_matchers:
                 public_name = public_matchers_by_matcher[matcher]
                 wrap(special_name, public_name)
     
@@ -428,10 +480,10 @@ class ExpectTest(TestCase):
             .to_raise(AssertionError, r"Tried to call non existing matcher 'nonexisting_matcher'")
     
     def test_should_ensure_not_is_on_word_boundaries(self):
-        expect(lambda: expect(True).nothing.to_be(True)).not_.to_raise()
-        expect(lambda: expect(True).annotation.to_be(True)).not_.to_raise()
-        expect(lambda: expect(True).an_not_ation.to_be(True)).to_raise()
-        expect(lambda: expect(True).an_not.to_be(True)).to_raise()
+        expect(lambda: expect(True).nothing_that_negates.is_(True)).not_.to_raise()
+        expect(lambda: expect(True).annotation.to.be(True)).not_.to_raise()
+        expect(lambda: expect(True).an_not_ation.to.be(True)).to_raise()
+        expect(lambda: expect(True).an_not.to.be(True)).to_raise()
     
     def test_should_allow_custom_messages(self):
         def messaging(message):
@@ -462,7 +514,7 @@ class ExpectTest(TestCase):
             assertion = a
         
         expect(assertion) != None
-        import sys, traceback
+        import traceback
         traceback = '\n'.join(traceback.format_tb(sys.exc_info()[2]))
         expect(traceback).not_to.contain('_assert')
         # Would like this one too, but is only hidden in py.test
@@ -476,14 +528,15 @@ class ExpectTest(TestCase):
         
         expect(lambda: None).not_to_raise(AssertionError)
         raising = lambda: expect(lambda: 1 / 0).not_to_raise(ZeroDivisionError)
-        expect(raising).to_raise(AssertionError, "integer division or modulo by zero")
+        expect(raising).to_raise(AssertionError, "division.* by zero")
     
     def _test_should_give_good_error_message_when_missing_argument_to_expect(self):
         pass
     
-    # Matchers
+    # Matchers ##########################################################################################
     
-    def test_is_trueish(self):
+    # REFACT: rename tests to use the canonical name
+    def test_trueish(self):
         expect(True).is_.trueish()
         expect(True).is_.truish()
         expect([1]).is_.trueish()
@@ -497,7 +550,7 @@ class ExpectTest(TestCase):
         expect(lambda: expect([1]).not_to_be.trueish()) \
             .to_raise(AssertionError, r"Expect \[1\] not to be trueish")
     
-    def test_is_falseish(self):
+    def test_falseish(self):
         expect(False).to.be.falsish()
         expect(False).to.be.falseish()
         expect(0).to.be.falseish()
@@ -509,7 +562,7 @@ class ExpectTest(TestCase):
         expect(lambda: expect('foo').to.be.falsish()) \
             .to_raise(AssertionError, r"")
     
-    def test_is_true(self):
+    def test_true(self):
         expect(True).true()
         expect(False).is_not.true()
         expect([1]).is_not.true()
@@ -520,7 +573,7 @@ class ExpectTest(TestCase):
         expect(lambda: expect(True).not_to_be.true()) \
             .to_raise(AssertionError, r"Expect True not to be True")
     
-    def test_is_false(self):
+    def test_false(self):
         expect(False).to.be.false()
         expect(None).not_to_be.false()
         expect([]).not_to_be.false()
@@ -533,7 +586,7 @@ class ExpectTest(TestCase):
         expect(lambda: expect(0).to.be.false()) \
             .to_raise(AssertionError, r"Expect 0 to be False")
     
-    def test_is_equal(self):
+    def test_equal(self):
         expect('foo').equals('foo')
         expect('foo').to.equal('foo')
         expect('foo').not_to.equal('fnord')
@@ -542,14 +595,16 @@ class ExpectTest(TestCase):
         expect(10) == 10
         expect(10) != 12
         
-        expect(lambda: expect([]) == set()).to_raise(AssertionError, r"Expect \[\] to be equal to set\(\[\]\)")
-        expect(lambda: expect(1) != 1).to_raise(AssertionError, r"Expect 1 not to be equal to 1")
+        expect(lambda: expect([]) == set()).to_raise(AssertionError, r"Expect \[\] to equal set")
+        expect(lambda: expect(1) != 1).to_raise(AssertionError, r"Expect 1 not to equal 1")
         expect(lambda: expect(23).to.equal(42)) \
-            .to_raise(AssertionError, r"Expect 23 to be equal to 42")
+            .to_raise(AssertionError, r"Expect 23 to equal 42")
         expect(lambda: expect(23).not_to.equal(23)) \
-            .to_raise(AssertionError, r"Expect 23 not to be equal to 23")
+            .to_raise(AssertionError, r"Expect 23 not to equal 23")
+        
+        # FIXME: make output multi line to make it easier to parse if individual output is longish
     
-    def test_is_identical(self):
+    def test_identical(self):
         expect(True).is_identical(True)
         expect(1).is_(1)
         expect(1).not_.to.be(2)
@@ -561,13 +616,20 @@ class ExpectTest(TestCase):
         expect(lambda: expect(1).not_to.be(1)) \
             .to_raise(AssertionError, r"Expect 1 not to be 1")
     
-    def test_is_none(self):
+    def test_none(self):
         expect(None).is_none()
         expect(0).is_not.none()
         expect(False).is_not.none()
         expect(lambda: expect(3).is_.none()).to_raise(AssertionError, r"Expect 3 to be None")
     
-    def test_is_included_in(self):
+    def test_exists(self):
+        expect(0).exists()
+        expect([]).exists()
+        expect(False).exists()
+        expect(None).does_not.exist()
+        
+        expect(lambda: expect(None).exists()).to_raise(AssertionError, r"Expect None to exist")
+    def test_included_in(self):
         expect(1).is_included_in(1,2,3)
         expect(1).is_included_in([1,2,3])
         expect(23).is_not.included_in(1,2,3)
@@ -601,7 +663,7 @@ class ExpectTest(TestCase):
         expect(dict(foo=['bar'])).to.have_subdict(foo=['bar'])
         
         expect(lambda: expect(42).has_subdict())\
-            .to_raise(AssertionError, r"Expect 42 to be a dictionary")
+            .to_raise(AssertionError, r"Expect 42 to be instance of 'dict'")
         
         expect(lambda: expect(dict()).to_have.subdict(foo='bar')) \
             .to_raise(AssertionError, r"Expect {} to contain dict {'foo': 'bar'}")
@@ -610,21 +672,22 @@ class ExpectTest(TestCase):
         expect(lambda: expect(dict(foo='bar')).not_to_have.subdict(foo='bar')) \
             .to_raise(AssertionError, r"Expect {'foo': 'bar'} not to contain dict {'foo': 'bar'}")
     
-    def test_is_matching(self):
+    def test_matching(self):
         expect("abbbababababaaaab").is_matching(r"[ab]+")
         expect("fnordabbafnord").matches(r"[ab]+")
         expect("cde").to_not.match(r"[ab]+")
         expect("fnord").matches(r"^fnord$")
         expect('bar').matches(r'\Abar\Z')
+        expect('bär').matches(r'\Abär\Z')
         
         expect(lambda: expect(32).matches("32"))\
-            .raises(AssertionError, r"Expect 32 to be a string")
+            .raises(AssertionError, r"Expect 32 to be instance of '.*str.*'")
         
         expect(lambda: expect('foo\nbar\nbaz').matches(r'^bar$')).to_raise(AssertionError)
         expect(lambda: expect('cde').matches(r'fnord')) \
             .to_raise(AssertionError, r"Expect 'cde' to be matched by regex r'fnord'")
     
-    def test_is_raising(self):
+    def test_raises(self):
         # is it an error to raise any other exception if a specific exception is expected? - yes
         # is it an error to raise any other exception if a specific exception is not expected? - could be ok, could be raised through
         
@@ -672,10 +735,14 @@ class ExpectTest(TestCase):
         expect(lambda: expect(raiser).not_.to_raise(NameError, r'fnord')).not_.to_raise()
         
         # Can catch exceptions that do not inherit from Exception to ensure everything is testable
-        import sys
         expect(lambda: sys.exit('gotcha')).to_raise(SystemExit)
+        
+        # Return caught exception
+        exception = expect(raiser).to_raise(TestException)
+        expect(exception).is_instance_of(TestException)
+        expect(str(exception)).matches('test_exception')
     
-    def test_is_empty(self):
+    def test_empty(self):
         expect("").is_empty()
         expect([]).is_empty()
         expect(tuple()).is_empty()
@@ -689,56 +756,77 @@ class ExpectTest(TestCase):
         expect(lambda: expect("23").is_empty()) \
             .to_raise(AssertionError, r"Expect '23' to be empty")
     
-    def test_is_instance(self):
+    def test_is_instance_of(self):
         expect(dict()).is_instance(dict)
         expect("").is_instance(str)
         
         expect(lambda: expect("").instanceof(list)).to_raise(AssertionError, r"Expect '' to be instance of 'list'")
     
+    def test_is_callable(self):
+        expect(lambda:None).is_callable()
+        def foo():pass
+        expect(foo).is_.callable()
+        expect(3).is_not.callable()
+        
+        expect(lambda: expect(3).is_.callable()) \
+            .raises(AssertionError, r"Expect 3 to be callable")
+    
     def test_has_length(self):
         expect("123").has_length(3)
         expect(set([1])).len(1)
         
-        expect(lambda: expect([1]).to_have.length(23)) \
-            .to_raise(AssertionError, r"Expect \[1\] to have length 23")
+        expect(lambda: expect([42]).to_have.length(23)) \
+            .to_raise(AssertionError, r"Expect \[42\] to have length 23, but found length 1")
     
-    def test_is_greater_then(self):
-        expect(3).is_greater_then(1)
+    def test_greater_than(self):
+        expect(3).is_greater_than(1)
         expect(3) > 1
-        expect(lambda: expect(10) > 15).to_raise(AssertionError, r"Expect 10 to be greater then 15")
-        expect(lambda: expect(1).is_greater_then(3)) \
-            .to_raise(AssertionError, r"Expect 1 to be greater then 3")
+        expect(lambda: expect(10) > 15).to_raise(AssertionError, r"Expect 10 to be greater than 15")
+        expect(lambda: expect(1).is_greater_than(3)) \
+            .to_raise(AssertionError, r"Expect 1 to be greater than 3")
     
-    def test_is_greater_or_equal_then(self):
-        expect(3).is_greater_or_equal_then(3)
-        expect(3).is_greater_or_equal_then(2)
+    def test_greater_or_equal_than(self):
+        expect(3).is_greater_or_equal_than(3)
+        expect(3).is_greater_or_equal_than(2)
         expect(7) >= 7
         expect(5) >= 2
         
-        expect(lambda: expect(20) >= 30).to_raise(AssertionError, r"Expect 20 to be greater or equal then 30")
+        expect(lambda: expect(20) >= 30).to_raise(AssertionError, r"Expect 20 to be greater or equal than 30")
     
-    def test_is_less_then(self):
-        expect(7).is_smaller_then(10)
+    def test_less_than(self):
+        expect(7).is_smaller_than(10)
         expect(10) < 12
-        expect(lambda: expect(10) < 3).to_raise(AssertionError, "Expect 10 to be less then 3")
+        expect(lambda: expect(10) < 3).to_raise(AssertionError, "Expect 10 to be less than 3")
     
-    def test_is_less_or_equal_then(self):
-        expect(10).is_smaller_or_equal_then(10)
+    def test_less_or_equal_than(self):
+        expect(10).is_smaller_or_equal_than(10)
         expect(10) <= 10
-        expect(lambda: expect(10) <= 5).raises(AssertionError, "Expect 10 to be less or equal then 5")
+        expect(lambda: expect(10) <= 5).raises(AssertionError, "Expect 10 to be less or equal than 5")
     
-    def test_is_within_range(self):
-        expect(3).is_within_range(1,10)
-        expect(lambda: expect(10).is_within_range(1,3)).to_raise(AssertionError, "Expect 10 to be between 1 and 3")
+    def test_between(self):
+        expect(3).is_between(1,10)
+        expect(lambda: expect(10).is_between(1,3)).to_raise(AssertionError, "Expect 10 to be between 1 and 3")
     
 
-    def test_is_close_to(self):
+    def test_close_to(self):
         expect(3.4).is_close_to(3, 0.5)
+        expect(-3.4).is_close_to(-3, 0.5)
         expect(3.4).is_close_to(3.1, 0.5)
         expect(3.4).is_close_to(10, 10)
         expect(10.2).not_to_be.close_to(3, 4)
+        expect(-3).is_not.close_to(-2, 0.5)
         
         expect(lambda: expect(10).is_.close_to(2, 3)).to_raise(AssertionError, "Expect 10 to be close to 2 with max delta 3")
     
+    def _test_increases_by(sel):
+        # Not sure what the right syntax for this should be
+        # increase_by, increases_by
+        # with expect(count_getter).increases_by(a_number):
+        #   increase_count()
+        # expect(increaser).to.increase_by(accessor, a_number)
+        # expect(increaser, accessor).increases_by(a_number)
+        pass
+    
+
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
